enableThinking property
Whether the app asked to see the model's reasoning. Off, it is requested off where the model can switch it off, and hidden either way.
Implementation
final bool enableThinking;
Whether the app asked to see the model's reasoning. Off, it is requested off where the model can switch it off, and hidden either way.
final bool enableThinking;