defaultCloseWaitLimit constant
How long callers may wait, in total, for an old embedder's close before reuseOrInvalidate gives up on them.
Implementation
@visibleForTesting
static const defaultCloseWaitLimit = Duration(seconds: 60);
How long callers may wait, in total, for an old embedder's close before reuseOrInvalidate gives up on them.
@visibleForTesting
static const defaultCloseWaitLimit = Duration(seconds: 60);