InstalledModelActivation class abstract interface

Internal contract used by core installers after all model files are ready.

This library is deliberately not exported from flutter_edge_ai.dart.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

activateInstalledModel(ModelSpec spec) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited