TtsBundleBase class sealed
Where a whole TTS bundle is installed from — the one base every manifest
file is resolved against by TtsModelTypeManifest.sourceFor. Internal: the
public surface is TtsInstallationBuilder's fromNetwork / fromAsset /
fromFile / fromBundled.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited