FlutterEdgeAiDesktop class
Desktop plugin is not available on web
- Inheritance
-
- Object
- PlatformInterface
- FlutterEdgeAiPlugin
- FlutterEdgeAiDesktop
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initializedEmbeddingModel → EmbeddingModel?
-
no setterinherited
- initializedModel → InferenceModel?
-
no setterinherited
- modelManager → ModelFileManager
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createEmbeddingModel(
{String? modelPath, String? tokenizerPath, PreferredBackend? preferredBackend}) → Future< EmbeddingModel> -
Creates and returns a new EmbeddingModel instance.
inherited
-
createModel(
{required ModelType modelType, ModelFileType fileType = ModelFileType.task, int maxTokens = 1024, PreferredBackend? preferredBackend, PreferredBackend? preferredVisionBackend, PreferredBackend? preferredAudioBackend, List< int> ? loraRanks, int? maxNumImages, bool supportImage = false, bool supportAudio = false, bool? enableSpeculativeDecoding, ActivationDataType? activationDataType, int? maxConcurrentSessions}) → Future<InferenceModel> -
Creates and returns a new InferenceModel instance.
inherited
-
createSttModel(
{String? modelPath, String? tokenizerPath, PreferredBackend? preferredBackend, String? language}) → Future< SpeechRecognizer> -
Creates and returns a new SpeechRecognizer instance.
inherited
-
createTtsModel(
{PreferredBackend? preferredBackend, String? language}) → Future< SpeechSynthesizer> -
Creates and returns a new SpeechSynthesizer for the active TTS model.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → FlutterEdgeAiDesktop
-
no setter
Static Methods
-
registerWith(
) → void